Commit a7dbac0b2372f9dd1af01ae058ec764d3979991f

nulltoken 2012-08-17T21:10:32

filemode: deploy enum usage

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
diff --git a/src/notes.c b/src/notes.c
index 6f9e777..b592a2c 100644
--- a/src/notes.c
+++ b/src/notes.c
@@ -180,7 +180,7 @@ static int manipulate_note_in_tree_r(
 	subtree_name[2] = '\0';
 
 	error = tree_write(out, repo, parent, git_tree_id(new),
-			   subtree_name, 0040000);
+			   subtree_name, GIT_FILEMODE_TREE);
 
 
 cleanup:
@@ -252,7 +252,13 @@ static int insert_note_in_tree_enotfound_cb(git_tree **out,
 	GIT_UNUSED(current_error);
 
 	/* No existing fanout at this level, insert in place */
-	return tree_write(out, repo, parent, note_oid, annotated_object_sha + fanout, 0100644);
+	return tree_write(
+		out,
+		repo,
+		parent,
+		note_oid,
+		annotated_object_sha + fanout,
+		GIT_FILEMODE_BLOB);
 }
 
 static int note_write(git_oid *out,
diff --git a/src/tree.c b/src/tree.c
index 0eee947..315269d 100644
--- a/src/tree.c
+++ b/src/tree.c
@@ -14,14 +14,14 @@
 #define DEFAULT_TREE_SIZE 16
 #define MAX_FILEMODE_BYTES 6
 
-static bool valid_attributes(const int attributes)
+static bool valid_filemode(const int filemode)
 {
-	return (attributes == 0040000	/* Directory */
-		|| attributes == 0100644 /* Non executable file */
-		|| attributes == 0100664 /* Non executable group writable file */
-		|| attributes == 0100755 /* Executable file */
-		|| attributes == 0120000 /* Symbolic link */
-		|| attributes == 0160000); /* Git link */
+	return (filemode == GIT_FILEMODE_TREE
+		|| filemode == GIT_FILEMODE_BLOB
+		|| filemode == GIT_FILEMODE_BLOB_GROUP_WRITABLE
+		|| filemode == GIT_FILEMODE_BLOB_EXECUTABLE
+		|| filemode == GIT_FILEMODE_LINK
+		|| filemode == GIT_FILEMODE_COMMIT);
 }
 
 static int valid_entry_name(const char *filename)
@@ -308,8 +308,8 @@ static int tree_parse_buffer(git_tree *tree, const char *buffer, const char *buf
 		int attr;
 
 		if (git__strtol32(&attr, buffer, &buffer, 8) < 0 ||
-			!buffer || !valid_attributes(attr))
-			return tree_error("Failed to parse tree. Can't parse attributes");
+			!buffer || !valid_filemode(attr))
+			return tree_error("Failed to parse tree. Can't parse filemode");
 
 		if (*buffer++ != ' ')
 			return tree_error("Failed to parse tree. Object is corrupted");
@@ -368,7 +368,7 @@ static int append_entry(
 	git_treebuilder *bld,
 	const char *filename,
 	const git_oid *id,
-	unsigned int attributes)
+	git_filemode_t filemode)
 {
 	git_tree_entry *entry;
 
@@ -376,7 +376,7 @@ static int append_entry(
 	GITERR_CHECK_ALLOC(entry);
 
 	git_oid_cpy(&entry->oid, id);
-	entry->attr = attributes;
+	entry->attr = (uint16_t)filemode;
 
 	if (git_vector_insert(&bld->entries, entry) < 0)
 		return -1;
@@ -517,17 +517,17 @@ static void sort_entries(git_treebuilder *bld)
 	git_vector_sort(&bld->entries);
 }
 
-GIT_INLINE(int) normalize_attributes(const int attributes)
+GIT_INLINE(git_filemode_t) normalize_filemode(git_filemode_t filemode)
 {
 	/* 100664 mode is an early design mistake. Tree entries may bear
 	 * this mode in some old git repositories, but it's now deprecated.
 	 * We silently normalize while inserting new entries in a tree 
 	 * being built.
 	 */
-	if (attributes == 0100664)
-		return 0100644;
+	if (filemode == GIT_FILEMODE_BLOB_GROUP_WRITABLE)
+		return GIT_FILEMODE_BLOB;
 
-	return attributes;
+	return filemode;
 }
 
 int git_treebuilder_create(git_treebuilder **builder_p, const git_tree *source)
@@ -553,7 +553,7 @@ int git_treebuilder_create(git_treebuilder **builder_p, const git_tree *source)
 			if (append_entry(
 				bld, entry_src->filename,
 				&entry_src->oid,
-				normalize_attributes(entry_src->attr)) < 0)
+				normalize_filemode((git_filemode_t)entry_src->attr)) < 0)
 				goto on_error;
 		}
 	}
@@ -571,17 +571,17 @@ int git_treebuilder_insert(
 	git_treebuilder *bld,
 	const char *filename,
 	const git_oid *id,
-	unsigned int attributes)
+	git_filemode_t filemode)
 {
 	git_tree_entry *entry;
 	int pos;
 
 	assert(bld && id && filename);
 
-	if (!valid_attributes(attributes))
-		return tree_error("Failed to insert entry. Invalid attributes");
+	if (!valid_filemode(filemode))
+		return tree_error("Failed to insert entry. Invalid filemode");
 
-	attributes = normalize_attributes(attributes);
+	filemode = normalize_filemode(filemode);
 
 	if (!valid_entry_name(filename))
 		return tree_error("Failed to insert entry. Invalid name for a tree entry");
@@ -598,7 +598,7 @@ int git_treebuilder_insert(
 	}
 
 	git_oid_cpy(&entry->oid, id);
-	entry->attr = attributes;
+	entry->attr = filemode;
 
 	if (pos < 0) {
 		if (git_vector_insert(&bld->entries, entry) < 0)
diff --git a/src/tree.h b/src/tree.h
index c49309c..24b517c 100644
--- a/src/tree.h
+++ b/src/tree.h
@@ -47,5 +47,9 @@ int git_tree__parse(git_tree *tree, git_odb_object *obj);
  */
 int git_tree__prefix_position(git_tree *tree, const char *prefix);
 
+/**
+ * Obsolete mode kept for compatibility reasons
+ */
+#define GIT_FILEMODE_BLOB_GROUP_WRITABLE 0100664
 
 #endif
diff --git a/tests-clar/index/filemodes.c b/tests-clar/index/filemodes.c
index 8bd35dd..75c94e8 100644
--- a/tests-clar/index/filemodes.c
+++ b/tests-clar/index/filemodes.c
@@ -100,40 +100,40 @@ void test_index_filemodes__untrusted(void)
 
 	/* 1 - add 0644 over existing 0644 -> expect 0644 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.0", 0644);
-	add_and_check_mode(index, "exec_off", 0100644);
+	add_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB);
 
 	/* 2 - add 0644 over existing 0755 -> expect 0755 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.0", 0644);
-	add_and_check_mode(index, "exec_on", 0100755);
+	add_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/* 3 - add 0755 over existing 0644 -> expect 0644 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.1", 0755);
-	add_and_check_mode(index, "exec_off", 0100644);
+	add_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB);
 
 	/* 4 - add 0755 over existing 0755 -> expect 0755 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.1", 0755);
-	add_and_check_mode(index, "exec_on", 0100755);
+	add_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/* 5 - append 0644 over existing 0644 -> expect 0644 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.2", 0644);
-	append_and_check_mode(index, "exec_off", 0100644);
+	append_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB);
 
 	/* 6 - append 0644 over existing 0755 -> expect 0755 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.2", 0644);
-	append_and_check_mode(index, "exec_on", 0100755);
+	append_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/* 7 - append 0755 over existing 0644 -> expect 0644 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.3", 0755);
-	append_and_check_mode(index, "exec_off", 0100644);
+	append_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB);
 
 	/* 8 - append 0755 over existing 0755 -> expect 0755 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.3", 0755);
-	append_and_check_mode(index, "exec_on", 0100755);
+	append_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/*  9 - add new 0644 -> expect 0644 */
 	cl_git_write2file("filemodes/new_off", "blah",
 		O_WRONLY | O_CREAT | O_TRUNC, 0644);
-	add_and_check_mode(index, "new_off", 0100644);
+	add_and_check_mode(index, "new_off", GIT_FILEMODE_BLOB);
 
 	/* this test won't give predictable results on a platform
 	 * that doesn't support filemodes correctly, so skip it.
@@ -142,7 +142,7 @@ void test_index_filemodes__untrusted(void)
 		/* 10 - add 0755 -> expect 0755 */
 		cl_git_write2file("filemodes/new_on", "blah",
 			O_WRONLY | O_CREAT | O_TRUNC, 0755);
-		add_and_check_mode(index, "new_on", 0100755);
+		add_and_check_mode(index, "new_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 	}
 
 	git_index_free(index);
@@ -168,45 +168,45 @@ void test_index_filemodes__trusted(void)
 
 	/* 1 - add 0644 over existing 0644 -> expect 0644 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.0", 0644);
-	add_and_check_mode(index, "exec_off", 0100644);
+	add_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB);
 
 	/* 2 - add 0644 over existing 0755 -> expect 0644 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.0", 0644);
-	add_and_check_mode(index, "exec_on", 0100644);
+	add_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB);
 
 	/* 3 - add 0755 over existing 0644 -> expect 0755 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.1", 0755);
-	add_and_check_mode(index, "exec_off", 0100755);
+	add_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/* 4 - add 0755 over existing 0755 -> expect 0755 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.1", 0755);
-	add_and_check_mode(index, "exec_on", 0100755);
+	add_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/* 5 - append 0644 over existing 0644 -> expect 0644 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.2", 0644);
-	append_and_check_mode(index, "exec_off", 0100644);
+	append_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB);
 
 	/* 6 - append 0644 over existing 0755 -> expect 0644 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.2", 0644);
-	append_and_check_mode(index, "exec_on", 0100644);
+	append_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB);
 
 	/* 7 - append 0755 over existing 0644 -> expect 0755 */
 	replace_file_with_mode("exec_off", "filemodes/exec_off.3", 0755);
-	append_and_check_mode(index, "exec_off", 0100755);
+	append_and_check_mode(index, "exec_off", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/* 8 - append 0755 over existing 0755 -> expect 0755 */
 	replace_file_with_mode("exec_on", "filemodes/exec_on.3", 0755);
-	append_and_check_mode(index, "exec_on", 0100755);
+	append_and_check_mode(index, "exec_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	/*  9 - add new 0644 -> expect 0644 */
 	cl_git_write2file("filemodes/new_off", "blah",
 		O_WRONLY | O_CREAT | O_TRUNC, 0644);
-	add_and_check_mode(index, "new_off", 0100644);
+	add_and_check_mode(index, "new_off", GIT_FILEMODE_BLOB);
 
 	/* 10 - add 0755 -> expect 0755 */
 	cl_git_write2file("filemodes/new_on", "blah",
 		O_WRONLY | O_CREAT | O_TRUNC, 0755);
-	add_and_check_mode(index, "new_on", 0100755);
+	add_and_check_mode(index, "new_on", GIT_FILEMODE_BLOB_EXECUTABLE);
 
 	git_index_free(index);
 }
diff --git a/tests-clar/object/tree/attributes.c b/tests-clar/object/tree/attributes.c
index ed88e74..cee72f1 100644
--- a/tests-clar/object/tree/attributes.c
+++ b/tests-clar/object/tree/attributes.c
@@ -4,9 +4,6 @@
 static const char *blob_oid = "3d0970ec547fc41ef8a5882dde99c6adce65b021";
 static const char *tree_oid  = "1b05fdaa881ee45b48cbaa5e9b037d667a47745e";
 
-#define GROUP_WRITABLE_FILE 0100664
-#define REGULAR_FILE 0100644
-
 void test_object_tree_attributes__ensure_correctness_of_attributes_on_insertion(void)
 {
 	git_treebuilder *builder;
@@ -16,9 +13,9 @@ void test_object_tree_attributes__ensure_correctness_of_attributes_on_insertion(
 
 	cl_git_pass(git_treebuilder_create(&builder, NULL));
 
-	cl_git_fail(git_treebuilder_insert(NULL, builder, "one.txt", &oid, 0777777));
-	cl_git_fail(git_treebuilder_insert(NULL, builder, "one.txt", &oid, 0100666));
-	cl_git_fail(git_treebuilder_insert(NULL, builder, "one.txt", &oid, 0000001));
+	cl_git_fail(git_treebuilder_insert(NULL, builder, "one.txt", &oid, (git_filemode_t)0777777));
+	cl_git_fail(git_treebuilder_insert(NULL, builder, "one.txt", &oid, (git_filemode_t)0100666));
+	cl_git_fail(git_treebuilder_insert(NULL, builder, "one.txt", &oid, (git_filemode_t)0000001));
 
 	git_treebuilder_free(builder);
 }
@@ -37,7 +34,7 @@ void test_object_tree_attributes__group_writable_tree_entries_created_with_an_an
 
 	entry = git_tree_entry_byname(tree, "old_mode.txt");
 	cl_assert_equal_i(
-		GROUP_WRITABLE_FILE,
+		GIT_FILEMODE_BLOB_GROUP_WRITABLE,
 		git_tree_entry_attributes(entry));
 
 	git_tree_free(tree);
@@ -63,10 +60,10 @@ void test_object_tree_attributes__normalize_attributes_when_inserting_in_a_new_t
 		builder,
 		"normalized.txt",
 		&bid,
-		GROUP_WRITABLE_FILE));
+		GIT_FILEMODE_BLOB_GROUP_WRITABLE));
 
 	cl_assert_equal_i(
-		REGULAR_FILE,
+		GIT_FILEMODE_BLOB,
 		git_tree_entry_attributes(entry));
 	
 	cl_git_pass(git_treebuilder_write(&tid, repo, builder));
@@ -76,7 +73,7 @@ void test_object_tree_attributes__normalize_attributes_when_inserting_in_a_new_t
 
 	entry = git_tree_entry_byname(tree, "normalized.txt");
 	cl_assert_equal_i(
-		REGULAR_FILE,
+		GIT_FILEMODE_BLOB,
 		git_tree_entry_attributes(entry));
 
 	git_tree_free(tree);
@@ -100,7 +97,7 @@ void test_object_tree_attributes__normalize_attributes_when_creating_a_tree_from
 	
 	entry = git_treebuilder_get(builder, "old_mode.txt");
 	cl_assert_equal_i(
-		REGULAR_FILE,
+		GIT_FILEMODE_BLOB,
 		git_tree_entry_attributes(entry));
 
 	cl_git_pass(git_treebuilder_write(&tid2, repo, builder));
@@ -110,7 +107,7 @@ void test_object_tree_attributes__normalize_attributes_when_creating_a_tree_from
 	cl_git_pass(git_tree_lookup(&tree, repo, &tid2));
 	entry = git_tree_entry_byname(tree, "old_mode.txt");
 	cl_assert_equal_i(
-		REGULAR_FILE,
+		GIT_FILEMODE_BLOB,
 		git_tree_entry_attributes(entry));
 
 	git_tree_free(tree);
diff --git a/tests-clar/object/tree/write.c b/tests-clar/object/tree/write.c
index 8b0f341..657bed2 100644
--- a/tests-clar/object/tree/write.c
+++ b/tests-clar/object/tree/write.c
@@ -35,11 +35,16 @@ void test_object_tree_write__from_memory(void)
 	cl_git_pass(git_tree_lookup(&tree, g_repo, &id));
 	cl_git_pass(git_treebuilder_create(&builder, tree));
 
-	cl_git_fail(git_treebuilder_insert(NULL, builder, "", &bid, 0100644));
-	cl_git_fail(git_treebuilder_insert(NULL, builder, "/", &bid, 0100644));
-	cl_git_fail(git_treebuilder_insert(NULL, builder, "folder/new.txt", &bid, 0100644));
+	cl_git_fail(git_treebuilder_insert(NULL, builder, "",
+		&bid, GIT_FILEMODE_BLOB));
+	cl_git_fail(git_treebuilder_insert(NULL, builder, "/",
+		&bid, GIT_FILEMODE_BLOB));
+	cl_git_fail(git_treebuilder_insert(NULL, builder, "folder/new.txt",
+		&bid, GIT_FILEMODE_BLOB));
+
+	cl_git_pass(git_treebuilder_insert(
+		NULL, builder, "new.txt", &bid, GIT_FILEMODE_BLOB));
 
-	cl_git_pass(git_treebuilder_insert(NULL,builder,"new.txt",&bid,0100644));
 	cl_git_pass(git_treebuilder_write(&rid, g_repo, builder));
 
 	cl_assert(git_oid_cmp(&rid, &id2) == 0);
@@ -63,14 +68,16 @@ void test_object_tree_write__subtree(void)
 
 	//create subtree
 	cl_git_pass(git_treebuilder_create(&builder, NULL));
-	cl_git_pass(git_treebuilder_insert(NULL,builder,"new.txt",&bid,0100644)); //-V536
+	cl_git_pass(git_treebuilder_insert(
+		NULL, builder, "new.txt", &bid, GIT_FILEMODE_BLOB)); //-V536
 	cl_git_pass(git_treebuilder_write(&subtree_id, g_repo, builder));
 	git_treebuilder_free(builder);
 
 	// create parent tree
 	cl_git_pass(git_tree_lookup(&tree, g_repo, &id));
 	cl_git_pass(git_treebuilder_create(&builder, tree));
-	cl_git_pass(git_treebuilder_insert(NULL,builder,"new",&subtree_id,040000)); //-V536
+	cl_git_pass(git_treebuilder_insert(
+		NULL, builder, "new", &subtree_id, GIT_FILEMODE_TREE)); //-V536
 	cl_git_pass(git_treebuilder_write(&id_hiearar, g_repo, builder));
 	git_treebuilder_free(builder);
 	git_tree_free(tree);
@@ -96,23 +103,23 @@ void test_object_tree_write__sorted_subtrees(void)
 		unsigned int attr;
 		const char *filename;
 	} entries[] = {
-		{ 0100644, ".gitattributes" },
-	  	{ 0100644, ".gitignore" },
-	  	{ 0100644, ".htaccess" },
-	  	{ 0100644, "Capfile" },
-	  	{ 0100644, "Makefile"},
-	  	{ 0100644, "README"},
-	  	{ 0040000, "app"},
-	  	{ 0040000, "cake"},
-	  	{ 0040000, "config"},
-	  	{ 0100644, "c"},
-	  	{ 0100644, "git_test.txt"},
-	  	{ 0100644, "htaccess.htaccess"},
-	  	{ 0100644, "index.php"},
-	  	{ 0040000, "plugins"},
-	  	{ 0040000, "schemas"},
-	  	{ 0040000, "ssl-certs"},
-	  	{ 0040000, "vendors"}
+		{ GIT_FILEMODE_BLOB, ".gitattributes" },
+	  	{ GIT_FILEMODE_BLOB, ".gitignore" },
+	  	{ GIT_FILEMODE_BLOB, ".htaccess" },
+	  	{ GIT_FILEMODE_BLOB, "Capfile" },
+	  	{ GIT_FILEMODE_BLOB, "Makefile"},
+	  	{ GIT_FILEMODE_BLOB, "README"},
+	  	{ GIT_FILEMODE_TREE, "app"},
+	  	{ GIT_FILEMODE_TREE, "cake"},
+	  	{ GIT_FILEMODE_TREE, "config"},
+	  	{ GIT_FILEMODE_BLOB, "c"},
+	  	{ GIT_FILEMODE_BLOB, "git_test.txt"},
+	  	{ GIT_FILEMODE_BLOB, "htaccess.htaccess"},
+	  	{ GIT_FILEMODE_BLOB, "index.php"},
+	  	{ GIT_FILEMODE_TREE, "plugins"},
+	  	{ GIT_FILEMODE_TREE, "schemas"},
+	  	{ GIT_FILEMODE_TREE, "ssl-certs"},
+	  	{ GIT_FILEMODE_TREE, "vendors"}
 	};
 
 	git_oid blank_oid, tree_oid;
diff --git a/include/git2/tree.h b/include/git2/tree.h
index 29aedac..9b61e7d 100644
--- a/include/git2/tree.h
+++ b/include/git2/tree.h
@@ -271,7 +271,7 @@ GIT_EXTERN(const git_tree_entry *) git_treebuilder_get(git_treebuilder *bld, con
  * @param bld Tree builder
  * @param filename Filename of the entry
  * @param id SHA1 oid of the entry
  * @param attributes Folder attributes of the entry. This parameter must
  *			be valued with one of the following entries: 0040000, 0100644,
  *			0100755, 0120000 or 0160000.
  * @return 0 or an error code
@@ -281,7 +281,7 @@ GIT_EXTERN(int) git_treebuilder_insert(
 	git_treebuilder *bld,
 	const char *filename,
 	const git_oid *id,
-	unsigned int attributes);
+	git_filemode_t filemode);
 
 /**
  * Remove an entry from the builder by its filename
@@ -271,7 +271,7 @@ GIT_EXTERN(const git_tree_entry *) git_treebuilder_get(git_treebuilder *bld, con
  * @param filename Filename of the entry
  * @param id SHA1 oid of the entry
- * @param attributes Folder attributes of the entry. This parameter must
+ * @param filemode Folder attributes of the entry. This parameter must
  *			be valued with one of the following entries: 0040000, 0100644,
  *			0100755, 0120000 or 0160000.